yakumo.keystone.v3.group

Package yakumo :: Package keystone :: Package v3 :: Module group |
[hide private]
[frames] | no frames]

# Source Code for Module yakumo.keystone.v3.group

     1  # Copyright 2014-2017 by Akira Yoshiyama <akirayoshiyama@gmail.com>.
     2  # All Rights Reserved.
     3  #
     4  #    Licensed under the Apache License, Version 2.0 (the "License"); you may
     5  #    not use this file except in compliance with the License. You may obtain
     6  #    a copy of the License at
     7  #
     8  #         http://www.apache.org/licenses/LICENSE-2.0
     9  #
    10  #    Unless required by applicable law or agreed to in writing, software
    11  #    distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
    12  #    WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
    13  #    License for the specific language governing permissions and limitations
    14  #    under the License.
    15
    16  """
    17  Resource class and its manager for groups in Identity V3 API
    18  """
    19
    20  from yakumo import base
    21  from yakumo.constant import UNDEF
    22  from yakumo import mapper
    23
    24
    25  ATTRIBUTE_MAPPING = [
    26      ('id', 'id', mapper.Noop),
    27      ('name', 'name', mapper.Noop),
    28      ('description', 'description', mapper.Noop),
    29      ('domain', 'domain_id', mapper.Resource('keystone.domain')),
    30  ]
    31
    32
    33 -class Resource(base.Resource):
    34      """resource class for groups on Identity V3 API"""
    35
    36 -    def update(self, name=UNDEF, description=UNDEF, domain=UNDEF):
    37          """
    38          Update properties of a group
    39
    40          @keyword name: Group name
    41          @type name: str
    42          @keyword description: Description
    43          @type description: str
    44          @keyword domain: Domain
    45          @type domain: yakumo.keystone.v3.domain.Resource
    46          @rtype: None
    47          """
    48          super(Resource, self).update(
    49              name=name,
    50              description=description,
    51              domain=domain)
    52
    53
    54 -class Manager(base.Manager):
    55      """manager class for groups on Identity V3 API"""
    56
    57      resource_class = Resource
    58      service_type = 'identity'
    59      _attr_mapping = ATTRIBUTE_MAPPING
    60      _json_resource_key = 'group'
    61      _json_resources_key = 'groups'
    62      _update_method = 'patch'
    63      _url_resource_path = '/groups'
    64
    65 -    def create(self, name=UNDEF, description=UNDEF, domain=UNDEF):
    66          """
    67          Register a group
    68
    69          @keyword name: Group name
    70          @type name: str
    71          @keyword description: Description
    72          @type description: str
    73          @keyword domain: Domain
    74          @type domain: yakumo.keystone.v3.domain.Resource
    75          @return: Created group
    76          @rtype: yakumo.keystone.v3.group.Resource
    77          """
    78          return super(Manager, self).create(
    79              name=name,
    80              description=description,
    81              domain=domain)
    82